summaryrefslogtreecommitdiff
path: root/Source/GetBMHD.S
diff options
context:
space:
mode:
authorChristian A. Weber <chris@gna.ch>1992-05-15 03:21:10 +0000
committerChristian A. Weber <chris@gna.ch>1992-05-15 03:21:10 +0000
commite556b972d1ad64453b3372b486191e2a59c91dda (patch)
tree4eb9264758c36cc75cdcf8daf8dde1517d77cb6a /Source/GetBMHD.S
parent36c824864c02f0a3f62c8a1d365d1670835c8c96 (diff)
downloadiff-library-e556b972d1ad64453b3372b486191e2a59c91dda.tar.gz
iff-library-e556b972d1ad64453b3372b486191e2a59c91dda.tar.bz2
iff-library-e556b972d1ad64453b3372b486191e2a59c91dda.zip
An neue Include-Files angepasst
Diffstat (limited to 'Source/GetBMHD.S')
-rw-r--r--Source/GetBMHD.S33
1 files changed, 17 insertions, 16 deletions
diff --git a/Source/GetBMHD.S b/Source/GetBMHD.S
index 35aec40..af18de4 100644
--- a/Source/GetBMHD.S
+++ b/Source/GetBMHD.S
@@ -1,13 +1,13 @@
**
-** $Id: $
-** $Revision: $
+** $Id: GetBMHD.S,v 1.1 92/05/12 22:26:34 chris Exp $
+** $Revision: 1.1 $
**
** $Filename: GetBMHD.S $
-** $Author: Christian A. Weber $
+** $Author: chris $
** $Release: 19.1 $
-** $Date: 92/05/11 21:11:27 $
+** $Date: 92/05/12 22:26:34 $
**
-** iff.library/IFFLib_GetBMHD
+** iff.library/IFFL_GetBMHD
**
** COPYRIGHT (C) 1987-1992 BY CHRISTIAN A. WEBER, BRUGGERWEG 2,
** CH-8037 ZUERICH, SWITZERLAND. ALL RIGHTS RESERVED. NO PART
@@ -17,7 +17,7 @@
**
- IDNT IFFLib_GetBMHD
+ IDNT IFFL_GetBMHD
SECTION text,CODE
INCLUDE "IffLib.i"
@@ -26,29 +26,29 @@
XDEF GetBMHDFunc
-******* iff.library/IFFLib_GetBMHD ******************************************
+******* iff.library/IFFL_GetBMHD ********************************************
*
* NAME
* IFFLib_GetBMHD -- find a BitMapHeader of an IFF-file
*
* SYNOPSIS
-* header = IFFLib_GetBMHD( ifffile )
-* D0 A1
+* header = IFFL_GetBMHD( iff )
+* D0 A1
*
-* struct BitMapHeader *IFFLib_GetBMHD( IFFFILE )
+* struct BitMapHeader *IFFL_GetBMHD( IFFL_HANDLE )
*
* FUNCTION
-* Returns a pointer to a 'BitMapHeader' structure as defined in
-* iff.h and iff.i
+* Returns a pointer to a BMHD (BitMapHeader) structure as defined
+* in iff.h and iff.i
*
* INPUTS
-* ifffile - IFF file pointer, returned by IFFLib_OpenIFF()
+* iff - IFF file handle, from IFFL_OpenIFF()
*
* RESULTS
* Pointer to the BitMapHeader, or NULL if no BMHD chunk found
*
* SEE ALSO
-* IFFLib_FindChunk(), IFFLib_GetColorTab()
+* IFFL_FindChunk(), IFFL_GetColorTab()
*
*****************************************************************************
@@ -57,7 +57,7 @@ GetBMHDFunc: movem.l d2/a5-a6,-(SP)
move.l #'BMHD',d0
bsr FindChunkFunc ; setzt Z-Flag wenn not found
bne.s 1$ ; Chunk gefunden --->
- moveq.l #IFF_NOBMHD,d0
+ moveq.l #IFFL_ERROR_NOBMHD,d0
bsr SetError
bra.s 99$
1$:
@@ -68,4 +68,5 @@ GetBMHDFunc: movem.l d2/a5-a6,-(SP)
99$: movem.l (SP)+,d2/a5-a6
rts
+
END
@@ -26,29 +26,29 @@
*
* NAME
-* IFFLib_GetBMHD -- find a BitMapHeader of an IFF-file
+* IFFL_GetBMHD -- find a BitMapHeader of an IFF-file
*
* SYNOPSIS